#[non_exhaustive]pub struct PipelineContext { /* private fields */ }Expand description
Context object provided when configuring a custom or standard request pipeline.
This context is passed to the factory function in:
Implementations
Sourceimpl PipelineContext
impl PipelineContext
Sourcepub fn resilience_context(&self) -> &HttpResilienceContext
pub fn resilience_context(&self) -> &HttpResilienceContext
Returns the resilience context used for configuring resilience patterns.
Sourcepub const fn redaction_engine(&self) -> &RedactionEngine
pub const fn redaction_engine(&self) -> &RedactionEngine
Returns the redaction engine used for sensitive data handling.
Sourcepub const fn body_builder(&self) -> &HttpBodyBuilder
pub const fn body_builder(&self) -> &HttpBodyBuilder
Returns the HTTP body builder used for constructing request and response bodies.